/* ********************************************************* operation.h *** *
 * ˴ؤؿ إåե
 *
 * Copyright (C) 2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
 * Okayama University
 *                                    Time-stamp: <05/04/25 23:31:50 sugaya>
 * ************************************************************************* */
#ifndef __OPERATION_H__
#define __OPERATION_H__

void	do_backup		(GList		*list);
void	restore_backup		(GList		*list);
void	original_image 		(GList		*list);
void	grayscale_image 	(GList		*list);
void	reverse_image		(GList		*list);
void	normalize_image		(GList		*list,
				 gdouble	min,
				 gdouble	max);
void	flip_horizontal 	(GList		*list);
void	flip_vertical 		(GList		*list);
void	scaling_by_scale	(GList		*list,
				 gdouble	xscale,
				 gdouble	yscale);
void	scaling_by_size 	(GList		*list,
				 gint		width,
				 gint		height);
void	rotate_90 		(GList		*list,
				 gboolean	counter_clockwise);

#endif /* __OPERATION_H__ */

/* ************************************************** End of operation.h *** */
